@@ -14,6 +14,12 @@
 # limitations under the License.
 
 
+# 认证失败。
+AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'
+
+# 操作失败。
+FAILEDOPERATION = 'FailedOperation'
+
 # 该操作不支持跨算法模型版本。
 FAILEDOPERATION_ACROSSVERSIONSERROR = 'FailedOperation.AcrossVersionsError'
 
@@ -242,6 +248,9 @@ INVALIDPARAMETERVALUE_UPLOADFACENUMEXCEED = 'InvalidParameterValue.UploadFaceNum
 # URL格式不合法。
 INVALIDPARAMETERVALUE_URLILLEGAL = 'InvalidParameterValue.UrlIllegal'
 
+# 超过配额限制。
+LIMITEXCEEDED = 'LimitExceeded'
+
 # 人脸个数超过限制。
 LIMITEXCEEDED_ERRORFACENUMEXCEED = 'LimitExceeded.ErrorFaceNumExceed'
 
