@@ -418,6 +418,34 @@ class IotcloudClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteDeviceResource(self, request):
+        """本接口（DeleteDeviceResource）用于删除设备资源
+
+        :param request: Request instance for DeleteDeviceResource.
+        :type request: :class:`tencentcloud.iotcloud.v20180614.models.DeleteDeviceResourceRequest`
+        :rtype: :class:`tencentcloud.iotcloud.v20180614.models.DeleteDeviceResourceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteDeviceResource", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteDeviceResourceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteLoraDevice(self, request):
         """删除lora类型的设备
 
@@ -950,6 +978,34 @@ class IotcloudClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeProduct(self, request):
+        """本接口（DescribeProduct）用于查看产品详情
+
+        :param request: Request instance for DescribeProduct.
+        :type request: :class:`tencentcloud.iotcloud.v20180614.models.DescribeProductRequest`
+        :rtype: :class:`tencentcloud.iotcloud.v20180614.models.DescribeProductResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeProduct", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeProductResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeProductResource(self, request):
         """本接口（DescribeProductResource）用于查询产品资源详情。
 
@@ -1230,6 +1286,34 @@ class IotcloudClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DownloadDeviceResource(self, request):
+        """本接口（DownloadDeviceResource）用于下载设备资源
+
+        :param request: Request instance for DownloadDeviceResource.
+        :type request: :class:`tencentcloud.iotcloud.v20180614.models.DownloadDeviceResourceRequest`
+        :rtype: :class:`tencentcloud.iotcloud.v20180614.models.DownloadDeviceResourceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DownloadDeviceResource", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DownloadDeviceResourceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def EditFirmware(self, request):
         """编辑固件信息
 
@@ -1790,6 +1874,34 @@ class IotcloudClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateProductDynamicRegister(self, request):
+        """更新产品动态注册的配置
+
+        :param request: Request instance for UpdateProductDynamicRegister.
+        :type request: :class:`tencentcloud.iotcloud.v20180614.models.UpdateProductDynamicRegisterRequest`
+        :rtype: :class:`tencentcloud.iotcloud.v20180614.models.UpdateProductDynamicRegisterResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateProductDynamicRegister", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateProductDynamicRegisterResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateTopicPolicy(self, request):
         """本接口（UpdateTopicPolicy）用于更新Topic信息
 
