@@ -279,90 +279,6 @@ class NlpClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeEntity(self, request):
-        """此接口正在维护升级，后续上线另行通知。
-
-        :param request: Request instance for DescribeEntity.
-        :type request: :class:`tencentcloud.nlp.v20190408.models.DescribeEntityRequest`
-        :rtype: :class:`tencentcloud.nlp.v20190408.models.DescribeEntityResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeEntity", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeEntityResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeRelation(self, request):
-        """此接口正在维护升级，后续上线另行通知。
-
-        :param request: Request instance for DescribeRelation.
-        :type request: :class:`tencentcloud.nlp.v20190408.models.DescribeRelationRequest`
-        :rtype: :class:`tencentcloud.nlp.v20190408.models.DescribeRelationResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeRelation", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeRelationResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def DescribeTriple(self, request):
-        """此接口正在维护升级，后续上线另行通知。
-
-        :param request: Request instance for DescribeTriple.
-        :type request: :class:`tencentcloud.nlp.v20190408.models.DescribeTripleRequest`
-        :rtype: :class:`tencentcloud.nlp.v20190408.models.DescribeTripleResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeTriple", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeTripleResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeWordItems(self, request):
         """依据自定义词库的ID，查询对应的词条信息。
 
