@@ -251,7 +251,7 @@ class PartnersClient(AbstractClient):
 
 
     def DescribeAgentDealsByCache(self, request):
-        """供超大型代理商（代客数量>=3000 ）拉取缓存的全量客户订单。
+        """供代理商拉取缓存的全量客户订单
 
         :param request: Request instance for DescribeAgentDealsByCache.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsByCacheRequest`
@@ -279,7 +279,7 @@ class PartnersClient(AbstractClient):
 
 
     def DescribeAgentDealsCache(self, request):
-        """【该接口将逐步下线，请切换使用升级版本DescribeAgentDealsByCache】供超大型代理商（代客数量>=3000 ）拉取缓存的全量客户订单。
+        """【该接口将逐步下线，请切换使用升级版本DescribeAgentDealsByCache】代理商拉取缓存的全量客户订单
 
         :param request: Request instance for DescribeAgentDealsCache.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentDealsCacheRequest`
@@ -391,7 +391,7 @@ class PartnersClient(AbstractClient):
 
 
     def DescribeAgentSelfPayDealsV2(self, request):
-        """可以查询代理商下指定客户的自付订单
+        """查询代理商名下指定代客的自付订单
 
         :param request: Request instance for DescribeAgentSelfPayDealsV2.
         :type request: :class:`tencentcloud.partners.v20180321.models.DescribeAgentSelfPayDealsV2Request`
@@ -474,36 +474,6 @@ class PartnersClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeClientBaseInfo(self, request):
-        """该接口即将下线，请切换调用DescribeClientBasicInfo。
-
-        国际站根据UIN查询代客基础信息【本接口仅限主账号访问】
-
-        :param request: Request instance for DescribeClientBaseInfo.
-        :type request: :class:`tencentcloud.partners.v20180321.models.DescribeClientBaseInfoRequest`
-        :rtype: :class:`tencentcloud.partners.v20180321.models.DescribeClientBaseInfoResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DescribeClientBaseInfo", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeClientBaseInfoResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeRebateInfos(self, request):
         """代理商可查询自己名下全部返佣信息
 
